@@ -1,19 +1,14 @@
 package Regexp::Parser;
 
-use strict;
-use warnings;
-
-our $VERSION = '0.21_02';
+$VERSION = '0.02';
 
 use 5.006;
 use Carp qw( carp croak );
-use base 'Exporter';
 use strict;
 use warnings;
 use charnames ();
 
 our %loaded;
-our @EXPORT = qw( Rx RxPOS RxCUR RxLEN Rf SIZE_ONLY LATEST );
 
 sub Rx :lvalue		{ $_[0]{regex} }
 sub RxPOS :lvalue	{ pos ${&Rx} }
@@ -29,19 +24,6 @@ use Regexp::Parser::Diagnostics;
 use Regexp::Parser::Objects;
 use Regexp::Parser::Handlers;
 
-
-# this handles 'use base "Regexp::Parser"'
-# which wouldn't call 'import'
-{
-  my ($level, $prev, $pkg);
-  while (my ($curr) = caller $level++) {
-    $pkg = $curr, last if $prev and $prev eq "base" and $curr ne "base";
-    $prev = $curr;
-  }
-  Regexp::Parser->export_to_level($level, $pkg, @EXPORT) if $pkg;
-}
-
-
 sub new {
   my ($class, $rx) = @_;
   my $self = bless {}, $class;
@@ -113,8 +95,8 @@ sub captures {
 
 
 sub nchar {
-  my $self = shift;
-  return map chr(/^\^(\S)/ ? (64 ^ ord $1) : charnames::vianame($_)), @_;
+  my ($self, $N) = @_;
+  return chr charnames::vianame($N);
 }
 
 
@@ -223,7 +205,6 @@ sub qr {
   $self->parse if $self->{stack};
   my $rx = $self->{tree};
   no warnings 'regexp';
-  use re 'eval';
 
   if (@$rx == 1 and $rx->[0]->family eq 'group') {
     my $vis = join "", map $_->qr, @{ $rx->[0]->{data} };
@@ -310,6 +291,8 @@ sub del_handler {
 
 __END__
 
+=cut
+
 =head1 NAME
 
 Regexp::Parser - base class for parsing regexes
@@ -320,7 +303,7 @@ See examples in L<"USAGE">.
 
 =head1 WARNING
 
-This is version B<0.022b>.  The documentation is (still) incomplete.  It
+This is version B<0.02>.  The documentation is (still) incomplete.  It
 may be a little jumbled or hard to understand.  If you find a problem,
 please let L<me|/"AUTHOR"> know.
 
@@ -687,8 +670,8 @@ in the future.  Module names are merely the author's suggestions.
 =item Regexp::WordBounds
 
 Adds handlers for C<< < >> and C<< > >> anchors, which match at the
-beginning and end of a "word", respectively.  C<< /</ >> is equivalent to
-C</(?!\w)(?=\w)/>, and C<< />/ >> is equivalent to C</(?<=\w)(?!\w)/>. (So
+beginning and end of a "word", respectively.  C<</</>> is equivalent to
+C</(?!\w)(?=\w)/>, and C<</>/>> is equivalent to C</(?<=\w)(?!\w)/>. (So
 that's the object's qr() method for you right there!)
 
 =item Regexp::MinLength
@@ -751,77 +734,6 @@ There are other possibilities as well.
 
 =head1 HISTORY
 
-=head2 0.022b -- July 6, 2004
-
-=over 4
-
-=item Hierarchy Changes
-
-There are now abstract classes I<anchor> and I<assertion>. You can't call
-their new() method directly, you can only call it through an object that
-inherits from that class.
-
-There are no longer I<star>, I<plus>, and I<curly> classes; they have been
-combined into one class, I<quantifier>.  You pass it the min and max,
-and the object's C<type> is determined dynamically.
-
-=item Character Class Hashes
-
-Character classes (I<anyof> objects) now have another attribute, C<charmap>,
-which is a hash reference holding character values (eg. 65 for 'A') and
-the number of times that character appeared in the character class.  The
-character class C<[A-CB-E]> would have a character map of C<< { 65 => 1, 66
-=> 2, 67 => 2, 68 => 1, 69 => 1} >>.  This will reflect ranges and embedded
-classes (such as C<[:cntrl:]> or C<\p{Print}>.
-
-=item Character Class Rendering
-
-The visual() method of I<anyof> objects will quell the repetition of any
-character in the class I<outside> of embedded classes, so the class
-C<[\w\d:4-65:]> will render as C<[\w\d:4-6]>.  If you want to prevent
-characters and ranges from being display if they are included in an embedded
-class, set the I<anyof> object's C<strict> attribute to 1; the character
-class would render as C<[\w\d:]>.  If you want to go even further and remove
-any embedded class that is I<entirely> redundant (that is, I<every>
-character in that embedded class is already found in the class), set the
-C<strict> attribute to 2; the class above would render as C<[\w:]>.
-
-=back
-
-=head2 0.021 -- July 3, 2004
-
-=over 4
-
-=item I<anyof_class> Changed
-
-If an I<anyof_class> element is a Unicode property or a Perl class (like
-C<\w> or C<\S>), the object's C<data> field points to the underlying
-object type (I<prop>, I<alnum>, etc.).  If the element is a POSIX class,
-the C<data> field is the string "POSIX".  POSIX classes don't exist in a
-regex outside of a character class, so I'm a little wary of making them
-objects in their own right, even if it would create a better sense of
-uniformity.
-
-=item Documentation
-
-Fixed some poor wording, and documented the problem with using F<SUPER::>
-inside F<MyClass::__object__>.
-
-=item Bug Fixes
-
-Character classes weren't closing properly in the tree.  Fixed.
-
-Standard escapes (C<\a>, C<\e>, etc.) were being returned as I<exact>
-nodes instead of I<anyof_char> nodes when inside character classes.  Fixed.
-(Mike Lambert)
-
-Non-grouping parentheses weren't being parsed properly.  Fixed.  (Mike
-Lambert)
-
-Flags weren't being turned off.  Fixed.
-
-=back
-
 =head2 0.02 -- July 1, 2004
 
 =over 4
